/****************************************************************************
** Meta object code from reading C++ file 'kotodoview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../korganizer-26.04.2/src/views/todoview/kotodoview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kotodoview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10KOTodoViewE_t {};
} // unnamed namespace

template <> constexpr inline auto KOTodoView::qt_create_metaobjectdata<qt_meta_tag_ZN10KOTodoViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KOTodoView",
        "purgeCompletedSignal",
        "",
        "unSubTodoSignal",
        "unAllSubTodoSignal",
        "configChanged",
        "fullViewChanged",
        "enabled",
        "setIncidenceChanger",
        "Akonadi::IncidenceChanger*",
        "changer",
        "showDates",
        "start",
        "end",
        "preferredMonth",
        "showIncidences",
        "Akonadi::Item::List",
        "incidenceList",
        "date",
        "updateView",
        "changeIncidenceDisplay",
        "Akonadi::Item",
        "incidence",
        "Akonadi::IncidenceChanger::ChangeType",
        "changeType",
        "updateConfig",
        "clearSelection",
        "printTodo",
        "printPreviewTodo"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'purgeCompletedSignal'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'unSubTodoSignal'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'unAllSubTodoSignal'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'configChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fullViewChanged'
        QtMocHelpers::SignalData<void(bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 },
        }}),
        // Slot 'setIncidenceChanger'
        QtMocHelpers::SlotData<void(Akonadi::IncidenceChanger *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'showDates'
        QtMocHelpers::SlotData<void(const QDate &, const QDate &, const QDate &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QDate, 12 }, { QMetaType::QDate, 13 }, { QMetaType::QDate, 14 },
        }}),
        // Slot 'showDates'
        QtMocHelpers::SlotData<void(const QDate &, const QDate &)>(11, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QDate, 12 }, { QMetaType::QDate, 13 },
        }}),
        // Slot 'showIncidences'
        QtMocHelpers::SlotData<void(const Akonadi::Item::List &, const QDate &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 }, { QMetaType::QDate, 18 },
        }}),
        // Slot 'updateView'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'changeIncidenceDisplay'
        QtMocHelpers::SlotData<void(const Akonadi::Item &, Akonadi::IncidenceChanger::ChangeType)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 }, { 0x80000000 | 23, 24 },
        }}),
        // Slot 'updateConfig'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clearSelection'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'printTodo'
        QtMocHelpers::SlotData<void(bool)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'printTodo'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'printPreviewTodo'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KOTodoView, qt_meta_tag_ZN10KOTodoViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KOTodoView::staticMetaObject = { {
    QMetaObject::SuperData::link<BaseView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KOTodoViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KOTodoViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10KOTodoViewE_t>.metaTypes,
    nullptr
} };

void KOTodoView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KOTodoView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->purgeCompletedSignal(); break;
        case 1: _t->unSubTodoSignal(); break;
        case 2: _t->unAllSubTodoSignal(); break;
        case 3: _t->configChanged(); break;
        case 4: _t->fullViewChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->setIncidenceChanger((*reinterpret_cast<std::add_pointer_t<Akonadi::IncidenceChanger*>>(_a[1]))); break;
        case 6: _t->showDates((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[3]))); break;
        case 7: _t->showDates((*reinterpret_cast<std::add_pointer_t<QDate>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 8: _t->showIncidences((*reinterpret_cast<std::add_pointer_t<Akonadi::Item::List>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDate>>(_a[2]))); break;
        case 9: _t->updateView(); break;
        case 10: _t->changeIncidenceDisplay((*reinterpret_cast<std::add_pointer_t<Akonadi::Item>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Akonadi::IncidenceChanger::ChangeType>>(_a[2]))); break;
        case 11: _t->updateConfig(); break;
        case 12: _t->clearSelection(); break;
        case 13: _t->printTodo((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->printTodo(); break;
        case 15: _t->printPreviewTodo(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::IncidenceChanger* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item::List >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::IncidenceChanger::ChangeType >(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Akonadi::Item >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KOTodoView::*)()>(_a, &KOTodoView::purgeCompletedSignal, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KOTodoView::*)()>(_a, &KOTodoView::unSubTodoSignal, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KOTodoView::*)()>(_a, &KOTodoView::unAllSubTodoSignal, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KOTodoView::*)()>(_a, &KOTodoView::configChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KOTodoView::*)(bool )>(_a, &KOTodoView::fullViewChanged, 4))
            return;
    }
}

const QMetaObject *KOTodoView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KOTodoView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10KOTodoViewE_t>.strings))
        return static_cast<void*>(this);
    return BaseView::qt_metacast(_clname);
}

int KOTodoView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BaseView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void KOTodoView::purgeCompletedSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KOTodoView::unSubTodoSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KOTodoView::unAllSubTodoSignal()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KOTodoView::configChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KOTodoView::fullViewChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
